收件箱界面 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Inbox Mailbox with some customizations as described in docs

Alex John Red Smith 1:33 pm Click to open this message
John Doe (4) 7:15 pm Clik to open this message right here
Philip Markov 10:15 am Photo booth beard raw denim letterpress vegan
Sabrina Yesterday Nullam quis risus eget urna mollis ornare
Philip Markov Yesterday Vestibulum id ligula porta felis euismod
Doctor Gomenz April 5 Vim te vivendo convenire, summo fuisset
Robin Hood April 4 No eos veniam equidem mentitum, his porro
Google Inc April 3 Convallis facilisis euismod urna sodales
Shrek March 28 Photo booth beard raw denim letterpress vegan messenger
Yahoo! March 27 Tofu biodiesel williamsburg marfa, four loko mcsweeney
Recipient:
Subject:
Message:
Attachments:
Clik to open this message
John Doe Today, 7:15 pm

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.

Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.

Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.

Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.

Attachments (2 files, 4.5 MB)

- Document1.pdf
- Sample.mp4

Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container